You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [33/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapCancel.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapCancel.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapRenewNegDuration.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapRenewNegDuration.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -40,14 +41,15 @@ public class LeaseMapRenewNegDuration ex
     private ServiceRegistration reg2;
     private LeaseMap lmap;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	reg1 = registerItem(new ServiceItem(null, new Long(0), null),
 			    getProxy());
 	reg2 = registerItem(new ServiceItem(null, new Long(1), null),
 			    getProxy());
 	lmap = prepareRegistrationLeaseMap(getRegistrationLease(reg1).createLeaseMap(-500));
 	lmap.put(getRegistrationLease(reg2), new Long(300));
+        return this;
     }
 
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ModifyAttributesBadClass.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ModifyAttributesBadClass.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ModifyAttributesBadClass.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ModifyAttributesBadClass.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -39,10 +40,11 @@ public class ModifyAttributesBadClass ex
 
     private ServiceRegistration reg;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	reg = registerItem(new ServiceItem(null, new Long(0), null),
 			   getProxy());
+        return this;
     }
 
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ModifyAttributesBadLength.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ModifyAttributesBadLength.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ModifyAttributesBadLength.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/ModifyAttributesBadLength.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -37,10 +38,11 @@ public class ModifyAttributesBadLength e
 
     private ServiceRegistration reg;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	reg = registerItem(new ServiceItem(null, new Long(0), null),
 			   getProxy());
+        return this;
     }
 
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyExceptionTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyExceptionTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyExceptionTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyExceptionTest.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -50,9 +51,10 @@ public abstract class NotifyExceptionTes
      *
      * Creates the lookup service and a do-nothing remote event listener.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	listener = new Listener();
+        return this;
     }
 
     /** Performs cleanup actions necessary to achieve a graceful exit of 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyOnAttrSet.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyOnAttrSet.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyOnComboAttrSet.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyOnComboAttrSet.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -140,7 +141,7 @@ public class NotifyOnComboAttrSet extend
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int transitionMask =   ServiceRegistrar.TRANSITION_MATCH_NOMATCH
                              | ServiceRegistrar.TRANSITION_NOMATCH_MATCH
@@ -165,7 +166,7 @@ public class NotifyOnComboAttrSet extend
         QATestUtils.setLeaseDuration(sysConfig,maxNMsToWaitForEvents);
 
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create the event handler */
 	listener = new Listener();
         /* load and create an initialized instance (non-null fields) of each
@@ -261,6 +262,7 @@ public class NotifyOnComboAttrSet extend
 			     Long.MAX_VALUE);
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.
@@ -271,7 +273,7 @@ public class NotifyOnComboAttrSet extend
      *       the "accumulation" vector with that information.
      *    2. Replaces (sets) all of the attributes belonging to the
      *       current service with the second set of attributes created 
-     *       during setup.
+     *       during construct.
      *    3. Verifies that the events expected are actually sent by the
      *       lookup service.
      *  @exception QATestException usually indicates test failure

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupAttributes.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupAttributes.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupGroups.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -59,9 +60,10 @@ public class SimpleAddLookupGroups exten
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	adminProxy = (JoinAdmin) super.getAdminProxy();
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupLocators.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupLocators.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddMemberGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddMemberGroups.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -58,9 +59,10 @@ public class SimpleAddMemberGroups exten
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	adminProxy = (DiscoveryAdmin) super.getAdminProxy();
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleModifyLookupAttributes.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleModifyLookupAttributes.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveLookupGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveLookupGroups.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -62,9 +63,10 @@ public class SimpleRemoveLookupGroups ex
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	adminProxy = (JoinAdmin) super.getAdminProxy();
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveLookupLocators.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveLookupLocators.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveMemberGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveMemberGroups.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -62,9 +63,10 @@ public class SimpleRemoveMemberGroups ex
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	adminProxy = (DiscoveryAdmin) super.getAdminProxy();
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetLookupGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetLookupGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetLookupGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetLookupGroups.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -61,9 +62,10 @@ public class SimpleSetLookupGroups exten
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	adminProxy = (JoinAdmin) super.getAdminProxy();
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetLookupLocators.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetLookupLocators.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetMemberGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetMemberGroups.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -59,9 +60,10 @@ public class SimpleSetMemberGroups exten
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	adminProxy = (DiscoveryAdmin) super.getAdminProxy();
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleUnicastPort.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleUnicastPort.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleUnicastPort.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleUnicastPort.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -52,9 +53,10 @@ public class SimpleUnicastPort extends Q
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	adminProxy = (DiscoveryAdmin) super.getAdminProxy();
+        return this;
     }
 
     /** Executes the current QA test.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set04/ModifyAttributesOverlap.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set04/ModifyAttributesOverlap.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set04/ModifyAttributesOverlap.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set04/ModifyAttributesOverlap.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set04;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -49,8 +50,8 @@ public class ModifyAttributesOverlap ext
     private Attr09 attr3;
     private Entry[] attrs;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 
 	attr0 = new Attr08();
 	attr0.setDefaults();
@@ -68,6 +69,7 @@ public class ModifyAttributesOverlap ext
 
 	reg = registerItem(new ServiceItem(null, new Long(0), attrs),
 			   getProxy());
+        return this;
     }
 
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set04/ModifyAttributesSwap.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set04/ModifyAttributesSwap.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set04/ModifyAttributesSwap.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set04/ModifyAttributesSwap.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set04;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -48,8 +49,8 @@ public class ModifyAttributesSwap extend
     private Attr08 attr3;
     private Entry[] attrs;
 
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 
 	attr0 = new Attr07();
 	attr0.setDefaults();
@@ -67,6 +68,7 @@ public class ModifyAttributesSwap extend
 
 	reg = registerItem(new ServiceItem(null, new Long(0), attrs),
 			   getProxy());
+        return this;
     }
 
     public void run() throws Exception {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/policyprovider/AbstractTestBase.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/policyprovider/AbstractTestBase.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/policyprovider/util/Util.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/policyprovider/util/Util.java Wed Jan  2 05:20:52 2013
@@ -37,7 +37,7 @@ import java.util.logging.Logger;
 import java.util.logging.Level;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalmanager/EventTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalmanager/EventTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalmanager/EventTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalmanager/EventTest.java Wed Jan  2 05:20:52 2013
@@ -34,25 +34,25 @@ import net.jini.lease.DesiredExpirationL
 import net.jini.lease.LeaseRenewalEvent;
 
 import com.sun.jini.qa.harness.TestException;
-
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 
 /**
  * Register a number of leases with various desired and actual expirations
  * and types of listeners and make sure that the correct events come back.
  */
-public class EventTest extends QATest {
+public class EventTest extends QATestEnvironment implements Test {
     /** The utility under test */
     private LeaseRenewalManager lrm;
 
     /**
      * Sets up the testing environment.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // output the name of this test
        logger.log(Level.FINE, "Test Name = " + this.getClass().getName());
@@ -63,6 +63,7 @@ public class EventTest extends QATest {
        // capture an instance of the Properties file.
        QAConfig config = (QAConfig)getConfig();
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AbstractLeaseRenewalServiceTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AbstractLeaseRenewalServiceTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AddRemoveTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AddRemoveTest.java Wed Jan  2 05:20:52 2013
@@ -30,7 +30,8 @@ import net.jini.lease.LeaseRenewalServic
 import net.jini.lease.LeaseRenewalSet;
 
 // com.sun.jini
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
 
@@ -49,17 +50,17 @@ public class AddRemoveTest extends Abstr
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "AddRemoveTest: In setup() method.");
 
        // instantiate a lease provider
        leaseProvider = new TestLeaseProvider(1);
-
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AssocExpWarnSetTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AssocExpWarnSetTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AssocExpWarnSetTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AssocExpWarnSetTest.java Wed Jan  2 05:20:52 2013
@@ -32,7 +32,8 @@ import net.jini.lease.RenewalFailureEven
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RememberingRemoteListener;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -68,10 +69,10 @@ public class AssocExpWarnSetTest extends
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 
        // Announce where we are in the test
        logger.log(Level.FINE, "AssocExpWarnTest: In setup() method.");
@@ -86,6 +87,7 @@ public class AssocExpWarnSetTest extends
 
        // create lease renewal manager for wider use across implementations
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AssocRenewalFailSetTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AssocRenewalFailSetTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AssocRenewalFailSetTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AssocRenewalFailSetTest.java Wed Jan  2 05:20:52 2013
@@ -33,7 +33,8 @@ import net.jini.lease.RenewalFailureEven
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RememberingRemoteListener;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -81,10 +82,10 @@ public class AssocRenewalFailSetTest ext
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "AssocRenewalFailSetTest: In setup() method.");
@@ -109,6 +110,7 @@ public class AssocRenewalFailSetTest ext
 
        // create lease renewal manager for wider use across implementations
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearEventRegistrationTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearEventRegistrationTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearEventRegistrationTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearEventRegistrationTest.java Wed Jan  2 05:20:52 2013
@@ -38,7 +38,8 @@ import net.jini.lease.RenewalFailureEven
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RememberingRemoteListener;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -89,10 +90,10 @@ public class ClearEventRegistrationTest 
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "ClearEventRegistrationTest: In setup() method.");
@@ -117,7 +118,7 @@ public class ClearEventRegistrationTest 
        // log event and then fail
        failingListener01 = new UnknownEventListener();
        failingListener02 = new UnknownEventListener();
-
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearFailureListenerTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearFailureListenerTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearFailureListenerTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearFailureListenerTest.java Wed Jan  2 05:20:52 2013
@@ -30,7 +30,8 @@ import net.jini.lease.LeaseRenewalSet;
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RememberingRemoteListener;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -78,10 +79,10 @@ public class ClearFailureListenerTest ex
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "ClearFailureListenerTest: In setup() method.");
@@ -103,6 +104,7 @@ public class ClearFailureListenerTest ex
 
        // create lease renewal manager for wider use across implementations
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearWarningListenerTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearWarningListenerTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearWarningListenerTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ClearWarningListenerTest.java Wed Jan  2 05:20:52 2013
@@ -34,7 +34,8 @@ import net.jini.lease.LeaseRenewalSet;
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RenewingRemoteListener;
 
 /**
@@ -68,10 +69,10 @@ public class ClearWarningListenerTest ex
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "ClearWarningListenerTest: In setup() method.");
@@ -85,6 +86,7 @@ public class ClearWarningListenerTest ex
 
        // logs events as they arrive and renews the lease
        rrl = new RenewingRemoteListener(getExporter(), renewSetDur);
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/DurationExpirationTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/DurationExpirationTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/DurationExpirationTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/DurationExpirationTest.java Wed Jan  2 05:20:52 2013
@@ -30,7 +30,8 @@ import net.jini.lease.LeaseRenewalSet;
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.BasicLeaseOwner;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -71,10 +72,10 @@ public class DurationExpirationTest exte
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "DurationExpirationTest: In setup() method.");
@@ -91,6 +92,7 @@ public class DurationExpirationTest exte
 
        // create lease renewal manager for wider use across implementations
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EqualsTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EqualsTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EqualsTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EqualsTest.java Wed Jan  2 05:20:52 2013
@@ -32,7 +32,8 @@ import com.sun.jini.qa.harness.TestExcep
 
 // com.sun.qa.
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * EqualsTest asserts that LRS equals method for proxies works as expected.
@@ -45,17 +46,17 @@ public class EqualsTest extends Abstract
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "EqualsTest: In setup() method.");
 
        // capture an instance of the Properties file.
        QAConfig config = (QAConfig) getConfig();
-
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventIDFailTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventIDFailTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventIDFailTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventIDFailTest.java Wed Jan  2 05:20:52 2013
@@ -33,7 +33,8 @@ import net.jini.lease.RenewalFailureEven
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RememberingRemoteListener;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -80,10 +81,10 @@ public class EventIDFailTest extends Abs
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "AssocRenewalFailSetTest: In setup() method.");
@@ -105,6 +106,7 @@ public class EventIDFailTest extends Abs
 
        // create lease renewal manager for wider use across implementations
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventIDWarnTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventIDWarnTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventIDWarnTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventIDWarnTest.java Wed Jan  2 05:20:52 2013
@@ -32,7 +32,8 @@ import net.jini.lease.ExpirationWarningE
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RememberingRemoteListener;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -69,10 +70,10 @@ public class EventIDWarnTest extends Abs
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "EventIDWarnTest: In setup() method.");
@@ -87,6 +88,7 @@ public class EventIDWarnTest extends Abs
 
        // create lease renewal manager for wider use across implementations
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventLeaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventLeaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventLeaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventLeaseTest.java Wed Jan  2 05:20:52 2013
@@ -38,7 +38,8 @@ import net.jini.lease.ExpirationWarningE
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RenewingRemoteListener;
 import com.sun.jini.test.share.RememberingRemoteListener;
 import com.sun.jini.test.share.TestLease;
@@ -115,10 +116,10 @@ public class EventLeaseTest extends Abst
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "EventLeaseTest: In setup() method.");
@@ -141,6 +142,7 @@ public class EventLeaseTest extends Abst
        // logs events as they arrive
        warnListener = new RememberingRemoteListener(getExporter());
        failListener = new RememberingRemoteListener(getExporter());
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventRegistrationTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventRegistrationTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventRegistrationTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventRegistrationTest.java Wed Jan  2 05:20:52 2013
@@ -31,7 +31,8 @@ import net.jini.lease.LeaseRenewalSet;
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RememberingRemoteListener;
 
 import net.jini.export.Exporter;
@@ -86,17 +87,17 @@ public class EventRegistrationTest exten
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "EventRegistrationTest: In setup() method.");
 
        // create lease renewal manager for wider use across implementations
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
-
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceFailTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceFailTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceFailTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceFailTest.java Wed Jan  2 05:20:52 2013
@@ -38,7 +38,8 @@ import net.jini.lease.RenewalFailureEven
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RenewingRemoteListener;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -88,10 +89,10 @@ public class EventSequenceFailTest exten
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "EventSequenceFailTest: In setup() method.");
@@ -112,6 +113,7 @@ public class EventSequenceFailTest exten
        // logs events as they arrive
        rrl01 = new RenewingRemoteListener(getExporter(), renewGrant);
        rrl02 = new RenewingRemoteListener(getExporter(), renewGrant);
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceTest.java Wed Jan  2 05:20:52 2013
@@ -35,7 +35,8 @@ import net.jini.lease.LeaseRenewalSet;
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RememberingRemoteListener;
 import com.sun.jini.test.share.TestLeaseProvider;
 import com.sun.jini.test.share.FailingOpCountingOwner;
@@ -122,10 +123,10 @@ public class EventSequenceTest extends A
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "EventSequenceTest: In setup() method.");
@@ -159,7 +160,7 @@ public class EventSequenceTest extends A
 
        // object from which test leases are obtained
        leaseProvider = new TestLeaseProvider(NUMBER_OF_TEST_LEASES);
-
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceWarnTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceWarnTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceWarnTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/EventSequenceWarnTest.java Wed Jan  2 05:20:52 2013
@@ -36,7 +36,8 @@ import net.jini.lease.LeaseRenewalSet;
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RenewingRemoteListener;
 
 /**
@@ -75,10 +76,10 @@ public class EventSequenceWarnTest exten
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "EventSequenceWarnTest: In setup() method.");
@@ -93,6 +94,7 @@ public class EventSequenceWarnTest exten
        // logs events as they arrive
        rrl01 = new RenewingRemoteListener(getExporter(), renewSetDur);
        rrl02 = new RenewingRemoteListener(getExporter(), renewSetDur);
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpirationListenerTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpirationListenerTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpirationListenerTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpirationListenerTest.java Wed Jan  2 05:20:52 2013
@@ -34,7 +34,8 @@ import net.jini.lease.LeaseRenewalSet;
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.RememberingRemoteListener;
 
 import java.util.logging.Level;
@@ -97,10 +98,10 @@ public class ExpirationListenerTest exte
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "ExpirationListenerTest: In setup() method.");
@@ -120,7 +121,7 @@ public class ExpirationListenerTest exte
 
        // logs events as they arrive
        rrl = new RememberingRemoteListener(getExporter());
-
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpireRemoveTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpireRemoveTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpireRemoveTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpireRemoveTest.java Wed Jan  2 05:20:52 2013
@@ -30,7 +30,8 @@ import net.jini.lease.LeaseRenewalServic
 import net.jini.lease.LeaseRenewalSet;
 
 // com.sun.jini
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.LeaseOwner;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -68,10 +69,10 @@ public class ExpireRemoveTest extends Ab
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "ExpireRemoveTest: In setup() method.");
@@ -85,7 +86,7 @@ public class ExpireRemoveTest extends Ab
 
        // create an owner for the lease
        owner = new OpCountingOwner(renewGrant);
-
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpireSetSleepTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpireSetSleepTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpireSetSleepTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/ExpireSetSleepTest.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import java.rmi.RemoteException;
 
 // 
 import com.sun.jini.qa.harness.TestException;
+import com.sun.jini.qa.harness.Test;
 
 // net.jini
 import net.jini.core.lease.Lease;
@@ -35,7 +36,7 @@ import net.jini.lease.LeaseRenewalServic
 import net.jini.lease.LeaseRenewalSet;
 
 // com.sun.jini
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.test.share.OpCountingOwner;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -83,10 +84,10 @@ public class ExpireSetSleepTest extends 
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "ExpireSetSleepTest: In setup() method.");
@@ -107,7 +108,7 @@ public class ExpireSetSleepTest extends 
 
        // create an owner for the lease
        owner = new OpCountingOwner(renewGrant);
-
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/GetLeaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/GetLeaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/GetLeaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/GetLeaseTest.java Wed Jan  2 05:20:52 2013
@@ -28,9 +28,10 @@ import net.jini.lease.LeaseRenewalSet;
 
 // 
 import com.sun.jini.qa.harness.TestException;
+import com.sun.jini.qa.harness.Test;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 
 /**
  * Assert that the getLease method returns the lease of the set itself.
@@ -46,16 +47,17 @@ public class GetLeaseTest extends Abstra
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "GetLeaseTest: In setup() method.");
 
        // create lease renewal manager for wider use across implementations
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
+       return this;
     }
 
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/GetLeasesTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/GetLeasesTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/GetLeasesTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/GetLeasesTest.java Wed Jan  2 05:20:52 2013
@@ -30,7 +30,8 @@ import net.jini.lease.LeaseRenewalSet;
 import com.sun.jini.qa.harness.TestException;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.BasicLeaseOwner;
 import com.sun.jini.test.share.TestLease;
 import com.sun.jini.test.share.TestLeaseProvider;
@@ -69,10 +70,10 @@ public class GetLeasesTest extends Abstr
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 	
        // Announce where we are in the test
        logger.log(Level.FINE, "GetLeasesTest: In setup() method.");
@@ -89,6 +90,7 @@ public class GetLeasesTest extends Abstr
 
        // create lease renewal manager for wider use across implementations
        lrm = new LeaseRenewalManager(sysConfig.getConfiguration());
+       return this;
     }
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/IllegalLeaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/IllegalLeaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/IllegalLeaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/IllegalLeaseTest.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import net.jini.lease.LeaseRenewalSet;
 
 // 
 import com.sun.jini.qa.harness.TestException;
+import com.sun.jini.qa.harness.Test;
 
 // com.sun.jini.qa
 import com.sun.jini.test.share.BasicLeaseOwner;
@@ -67,10 +68,10 @@ public class IllegalLeaseTest extends Ab
     /**
      * Sets up the testing environment.
      */
-    public void setup(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
+    public Test construct(com.sun.jini.qa.harness.QAConfig sysConfig) throws Exception {
 
        // mandatory call to parent
-       super.setup(sysConfig);
+       super.construct(sysConfig);
 
        // Announce where we are in the test
        logger.log(Level.FINE, "IllegalLeaseTest: In setup() method.");
@@ -84,6 +85,7 @@ public class IllegalLeaseTest extends Ab
 
        // create an owner to for testing definite exceptions
        leaseOwner = new BasicLeaseOwner(renewGrant);
+       return this;
     }
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapCancel.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapCancel.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -89,9 +90,9 @@ public class LeaseMapCancel extends QATe
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	listener = new Listener();
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
@@ -112,6 +113,7 @@ public class LeaseMapCancel extends QATe
 	evntLeases = new Lease[nInstances];
 	registerAllEvents();
 	createLeaseMap();
+        return this;
    }
 
     /** Executes the current QA test. */
@@ -145,7 +147,7 @@ public class LeaseMapCancel extends QATe
 
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
      * corresponding template created during setup and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 
      * event notification registration process.
@@ -145,7 +147,7 @@ public class LeaseMapCancel extends QATe
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
-     * corresponding template created during setup and corresponding to
+     * corresponding template created during construct and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapRenew.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapRenew.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapRenew.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapRenew.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -93,17 +94,17 @@ public class LeaseMapRenew extends QATes
      *  registered service items. 
      *  <p>
      *  The initial lease duration is greater than the lease renewal
      *  duration to accomodate systems with excessive setup times.
      *  Some test systems were observed to require more than 15 seconds
      *  for setup, which caused the early leases to expire before the
      *  first leasemap renewal call.
      *
      *  @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i;
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	listener = new Listener();
         nInstances = super.getNInstances();
 	srvcItems = super.createServiceItems(TEST_SRVC_CLASSES);
@@ -127,6 +128,7 @@ public class LeaseMapRenew extends QATes
 	registerAllEvents();
 	createLeaseMap();
 	logger.log(Level.FINEST, "setup complete");
+        return this;
    }
 
     /** Executes the current QA test.
@@ -198,7 +200,7 @@ public class LeaseMapRenew extends QATes
 
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
      * corresponding template created during setup and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 
      * event notification registration process.
@@ -93,17 +94,17 @@ public class LeaseMapRenew extends QATes
      *  <p>
      *  The initial lease duration is greater than the lease renewal
-     *  duration to accomodate systems with excessive setup times.
+     *  duration to accomodate systems with excessive construct times.
      *  Some test systems were observed to require more than 15 seconds
@@ -93,17 +94,17 @@ public class LeaseMapRenew extends QATes
      *  Some test systems were observed to require more than 15 seconds
-     *  for setup, which caused the early leases to expire before the
+     *  for construct, which caused the early leases to expire before the
      *  first leasemap renewal call.
      *
@@ -198,7 +200,7 @@ public class LeaseMapRenew extends QATes
     /* For each registered service, registers an event notification request,
      * with a specified lease duration, based on the contents of the 
-     * corresponding template created during setup and corresponding to
+     * corresponding template created during construct and corresponding to
      * the appropriate transition mask. Populates the array of Leases so
      * that each element contains one of the event leases returned by the 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapRenewNegDuration.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/LeaseMapRenewNegDuration.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyOnAttrSet.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyOnAttrSet.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set02;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -110,14 +111,14 @@ public class NotifyOnAttrSet extends QAT
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         ServiceID curSrvcID;
 	EventRegistration[] evntRegs;
         int regTransitions =   ServiceRegistrar.TRANSITION_MATCH_MATCH
                              | ServiceRegistrar.TRANSITION_MATCH_NOMATCH;
         /* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
         /* create a single event handler to process all received events */
 	listener = new Listener();
         /* load and instantiate a set of initialized (non-null fields) 
@@ -177,13 +178,14 @@ public class NotifyOnAttrSet extends QAT
 			     Long.MAX_VALUE);
 	    evntRegs[i] = prepareEventRegistration(evntRegs[i]);
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each service instance created during setup, calls setAttributes()
      *  to replace that service's attribute with the corresponding attribute
      *  from the second set of attributes created during setup. Waits a
      *  configured amount of time to allow for all of the events to be 
      *  generated and collected. Determines if all of the expected -- as well 
      *  as no un-expected -- events have arrived. This test depends on the 
@@ -177,13 +178,14 @@ public class NotifyOnAttrSet extends QAT
     /** Executes the current QA test.
      *
-     *  For each service instance created during setup, calls setAttributes()
+     *  For each service instance created during construct, calls setAttributes()
      *  to replace that service's attribute with the corresponding attribute
@@ -177,13 +178,14 @@ public class NotifyOnAttrSet extends QAT
      *  to replace that service's attribute with the corresponding attribute
-     *  from the second set of attributes created during setup. Waits a
+     *  from the second set of attributes created during construct. Waits a
      *  configured amount of time to allow for all of the events to be 
      *  generated and collected. Determines if all of the expected -- as well 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyOnComboAttrSet.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set02/NotifyOnComboAttrSet.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupAttributes.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupAttributes.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -62,9 +63,9 @@ public class SimpleAddLookupAttributes e
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 	/* Create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	/* retrieve the proxy to the JoinAdmin methods */
 	adminProxy = (JoinAdmin) super.getAdminProxy();
 	/* populate the expectedAttrs array with the names of both the
@@ -85,6 +86,7 @@ public class SimpleAddLookupAttributes e
 	    Class loadedAttrObj = Class.forName(ATTR_CLASSES[i]);
 	    attrInstances[i] = (Entry)loadedAttrObj.newInstance();
 	}
+        return this;
     }
 
     /** Executes the current QA test.
@@ -92,7 +94,7 @@ public class SimpleAddLookupAttributes e
      *  Retrieves the initial set of attribute classes belonging to the
      *  Registrar and then verifies that this set contains the expected
      *  set of classes. Invokes addLookupAttributes() to add to the 
      *  Registrar the set of attribute instances created in setup.
      *  Retrieves the set of attribute classes belonging to the Registrar
      *  and verifies that this set contains the expected classes.
      *  @exception QATestException usually indicates test failure
@@ -113,7 +115,7 @@ public class SimpleAddLookupAttributes e
 				  + "is NOT equal to the set expected");
 	}
 	/* invoke addLookupAttributes() to add to the Registrar the set of
 	 * attribute instances created in setup
 	 */
 	adminProxy.addLookupAttributes(attrInstances);
 	/* retrieve the set of attribute classes belonging to the Registrar
@@ -92,7 +94,7 @@ public class SimpleAddLookupAttributes e
      *  Registrar and then verifies that this set contains the expected
      *  set of classes. Invokes addLookupAttributes() to add to the 
-     *  Registrar the set of attribute instances created in setup.
+     *  Registrar the set of attribute instances created in construct.
      *  Retrieves the set of attribute classes belonging to the Registrar
      *  and verifies that this set contains the expected classes.
@@ -113,7 +115,7 @@ public class SimpleAddLookupAttributes e
 	}
 	/* invoke addLookupAttributes() to add to the Registrar the set of
-	 * attribute instances created in setup
+	 * attribute instances created in construct
 	 */
 	adminProxy.addLookupAttributes(attrInstances);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupLocators.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddLookupLocators.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -65,9 +66,9 @@ public class SimpleAddLookupLocators ext
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 	/* Create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	/* retrieve the proxy to the JoinAdmin methods */
 	adminProxy = (JoinAdmin) super.getAdminProxy();
 	/* load the LookupLocator class and create an instance of this class
@@ -77,6 +78,7 @@ public class SimpleAddLookupLocators ext
 	for (int i=0;i<HOST_ARGS.length;i++) {
 	    locators[i] = QAConfig.getConstrainedLocator(HOST_ARGS[i],PORT_ARGS[i]);
 	}
+        return this;
     }
 
     /** Executes the current QA test.
@@ -84,7 +86,7 @@ public class SimpleAddLookupLocators ext
      *  Retrieves the initial set of locators belonging to the Registrar
      *  and verifies that this set contains the expected set of classes
      *  (currently, should be empty). Invokes addLookupLocators() to add 
      *  to the Registrar the set of locator instances created in setup.
      *  Retrieves the set of LookupLocators belonging to the Registrar
      *  and verifies that this set contains the expected elements.
      *  @exception QATestException usually indicates test failure
@@ -84,7 +86,7 @@ public class SimpleAddLookupLocators ext
      *  and verifies that this set contains the expected set of classes
      *  (currently, should be empty). Invokes addLookupLocators() to add 
-     *  to the Registrar the set of locator instances created in setup.
+     *  to the Registrar the set of locator instances created in construct.
      *  Retrieves the set of LookupLocators belonging to the Registrar
      *  and verifies that this set contains the expected elements.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddMemberGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleAddMemberGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleModifyLookupAttributes.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleModifyLookupAttributes.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -93,9 +94,9 @@ public class SimpleModifyLookupAttribute
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 	/* create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	/* retrieve the proxy to the JoinAdmin methods */
 	adminProxy = (JoinAdmin) super.getAdminProxy();
 
@@ -137,6 +138,7 @@ public class SimpleModifyLookupAttribute
         for(int i=initialAttrs.length,j=0;i<expectedModAttrs.length;i++,j++){
             expectedModAttrs[i] = modAttrs[j];
 	}
+        return this;
     }
 
     /** Executes the current QA test.
@@ -144,12 +146,12 @@ public class SimpleModifyLookupAttribute
      *  Retrieves the initial set of attribute classes belonging to the
      *  Registrar and then verifies that this set contains the expected
      *  set of classes. Invokes addLookupAttributes() to add to the 
      *  Registrar the set of attribute instances created in setup; and
      *  then retrieves all attributes belonging to the Registrar and
      *  verifies that the retrieved set contains the expected classes.
      *  Invokes modifyLookupAttributes() to modify the first set of
      *  attributes added to the Registrar with the second set of attributes
      *  created in setup; and then retrieves all attributes belonging to 
      *  the Registrar and verifies that the retrieved set contains the
      *  expected classes.
      *  @exception QATestException usually indicates test failure
@@ -172,7 +174,7 @@ public class SimpleModifyLookupAttribute
 	    }
 	}
 	/* invoke addLookupAttributes() to add to the Registrar the first 
 	 * set of attribute instances created in setup
 	 */
 	adminProxy.addLookupAttributes(addAttrs);
 	/* retrieve the current set of attribute classes belonging to the
@@ -193,7 +195,7 @@ public class SimpleModifyLookupAttribute
 	}
 	/* invoke modifyLookupAttributes() to modify the first set of
 	 * attributes added to the Registrar with the second set of attributes
 	 * created in setup
 	 */
 	adminProxy.modifyLookupAttributes(addAttrs,modAttrs);
 	/* retrieve the current set of attribute classes belonging to the
@@ -144,12 +146,12 @@ public class SimpleModifyLookupAttribute
      *  Registrar and then verifies that this set contains the expected
      *  set of classes. Invokes addLookupAttributes() to add to the 
-     *  Registrar the set of attribute instances created in setup; and
+     *  Registrar the set of attribute instances created in construct; and
      *  then retrieves all attributes belonging to the Registrar and
      *  verifies that the retrieved set contains the expected classes.
@@ -144,12 +146,12 @@ public class SimpleModifyLookupAttribute
      *  Invokes modifyLookupAttributes() to modify the first set of
      *  attributes added to the Registrar with the second set of attributes
-     *  created in setup; and then retrieves all attributes belonging to 
+     *  created in construct; and then retrieves all attributes belonging to 
      *  the Registrar and verifies that the retrieved set contains the
      *  expected classes.
@@ -172,7 +174,7 @@ public class SimpleModifyLookupAttribute
 	}
 	/* invoke addLookupAttributes() to add to the Registrar the first 
-	 * set of attribute instances created in setup
+	 * set of attribute instances created in construct
 	 */
 	adminProxy.addLookupAttributes(addAttrs);
@@ -193,7 +195,7 @@ public class SimpleModifyLookupAttribute
 	/* invoke modifyLookupAttributes() to modify the first set of
 	 * attributes added to the Registrar with the second set of attributes
-	 * created in setup
+	 * created in construct
 	 */
 	adminProxy.modifyLookupAttributes(addAttrs,modAttrs);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveLookupGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveLookupGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveLookupLocators.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveLookupLocators.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -77,9 +78,9 @@ public class SimpleRemoveLookupLocators 
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 	/* Create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	/* retrieve the proxy to the JoinAdmin methods */
 	adminProxy = (JoinAdmin) super.getAdminProxy();
 	/* load the LookupLocator class and create an instance of this class
@@ -101,6 +102,7 @@ public class SimpleRemoveLookupLocators 
 	    expectedLocators[k] = addLocators[i];
 	    k++;
 	}
+        return this;
     }
 
     /** Executes the current QA test.
@@ -108,7 +110,7 @@ public class SimpleRemoveLookupLocators 
      *  Retrieves the initial set of locators belonging to the Registrar
      *  and verifies that this set contains the expected set of classes
      *  (currently, should be empty). Invokes addLookupLocators() to add 
      *  to the Registrar the set of locator instances created in setup.
      *  Retrieves the set of LookupLocators belonging to the Registrar
      *  and verifies that this set contains the expected elements. Invokes
      *  removeLookupLocators() to remove the sub-set of locators designated
@@ -143,7 +145,7 @@ public class SimpleRemoveLookupLocators 
 					+(addLocators[i]).getClass()+")");
 	    }
 	}
 	/* remove the set of locators created in setup from the Registrar */
 	adminProxy.removeLookupLocators(removeLocators);
 	/* retrieve all locators belonging to the Registrar and verify
 	 * that this set contains the expected elements
@@ -108,7 +110,7 @@ public class SimpleRemoveLookupLocators 
      *  and verifies that this set contains the expected set of classes
      *  (currently, should be empty). Invokes addLookupLocators() to add 
-     *  to the Registrar the set of locator instances created in setup.
+     *  to the Registrar the set of locator instances created in construct.
      *  Retrieves the set of LookupLocators belonging to the Registrar
      *  and verifies that this set contains the expected elements. Invokes
@@ -143,7 +145,7 @@ public class SimpleRemoveLookupLocators 
 	    }
 	}
-	/* remove the set of locators created in setup from the Registrar */
+	/* remove the set of locators created in construct from the Registrar */
 	adminProxy.removeLookupLocators(removeLocators);
 	/* retrieve all locators belonging to the Registrar and verify

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveMemberGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleRemoveMemberGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetLookupLocators.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetLookupLocators.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set03;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.TestException;
@@ -77,9 +78,9 @@ public class SimpleSetLookupLocators ext
      *  @exception QATestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
 	/* Create the lookup service */
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	/* retrieve the proxy to the JoinAdmin methods */
 	adminProxy = (JoinAdmin) super.getAdminProxy();
 	/* load the LookupLocator class */
@@ -96,6 +97,7 @@ public class SimpleSetLookupLocators ext
 	for (int i=0,j=0;i<SET_HOSTS.length;i++) {
 	    setLocators[i] = QAConfig.getConstrainedLocator(SET_HOSTS[i],SET_PORTS[i]);
 	}
+        return this;
     }
 
     /** Executes the current QA test.
@@ -103,11 +105,11 @@ public class SimpleSetLookupLocators ext
      *  Retrieves the initial set of locators belonging to the Registrar
      *  and verifies that this set contains the expected set of classes
      *  (currently, should be empty). Invokes addLookupLocators() to add 
      *  to the Registrar the set of locator instances created in setup.
      *  Retrieves the set of LookupLocators belonging to the Registrar
      *  and verifies that this set contains the expected elements. Invokes
      *  setLookupLocators() to replace the current set of locators in
      *  Registrar with the the set of locators created in setup. Retrieves
      *  the set of LookupLocators belonging to the Registrar and verifies
      *  that this set contains the expected elements. 
      *  @exception QATestException usually indicates test failure
@@ -140,7 +142,7 @@ public class SimpleSetLookupLocators ext
 	    }
 	}
 	/* replace (set) the set of locators added above with the second set
 	 * of locators created in setup
 	 */
 	adminProxy.setLookupLocators(setLocators);
 	/* retrieve all locators belonging to the Registrar and verify
@@ -103,11 +105,11 @@ public class SimpleSetLookupLocators ext
      *  and verifies that this set contains the expected set of classes
      *  (currently, should be empty). Invokes addLookupLocators() to add 
-     *  to the Registrar the set of locator instances created in setup.
+     *  to the Registrar the set of locator instances created in construct.
      *  Retrieves the set of LookupLocators belonging to the Registrar
      *  and verifies that this set contains the expected elements. Invokes
@@ -103,11 +105,11 @@ public class SimpleSetLookupLocators ext
      *  and verifies that this set contains the expected elements. Invokes
      *  setLookupLocators() to replace the current set of locators in
-     *  Registrar with the the set of locators created in setup. Retrieves
+     *  Registrar with the the set of locators created in construct. Retrieves
      *  the set of LookupLocators belonging to the Registrar and verifies
      *  that this set contains the expected elements. 
@@ -140,7 +142,7 @@ public class SimpleSetLookupLocators ext
 	}
 	/* replace (set) the set of locators added above with the second set
-	 * of locators created in setup
+	 * of locators created in construct
 	 */
 	adminProxy.setLookupLocators(setLocators);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetMemberGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set03/SimpleSetMemberGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/policyprovider/AbstractTestBase.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/policyprovider/AbstractTestBase.java Wed Jan  2 05:20:52 2013
@@ -22,9 +22,9 @@ import java.util.logging.Level;
 // com.sun.jini.qa.harness
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
-
+import com.sun.jini.qa.harness.Test;
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
 
 // java.net
@@ -63,7 +63,7 @@ import com.sun.jini.test.spec.policyprov
  * This class sets up the testing environment and
  * has some helper methods.
  */
-public abstract class AbstractTestBase extends QATest {
+public abstract class AbstractTestBase extends QATestEnvironment implements Test {
 
     /** java.security.policy property string */
     protected static final String SECURITYPOLICY = "java.security.policy";
@@ -113,11 +113,11 @@ public abstract class AbstractTestBase e
     /**
      * Sets up the testing environment.
      *
      * @param sysConfig QAConfig from the runner for setup.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         // mandatory call to parent
-        super.setup(sysConfig);
+        super.construct(sysConfig);
 
         // set up parent's config.
         this.config = (QAConfig) getConfig();
@@ -129,6 +129,7 @@ public abstract class AbstractTestBase e
          *
          */
         port = config.getIntConfigVal("com.sun.jini.test.port", 8082);
+        return this;
     }
 
     /**
@@ -113,11 +113,11 @@ public abstract class AbstractTestBase e
      * Sets up the testing environment.
      *
-     * @param sysConfig QAConfig from the runner for setup.
+     * @param sysConfig QAConfig from the runner for construct.
      */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/policyprovider/util/Util.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/policyprovider/util/Util.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AbstractLeaseRenewalServiceTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AbstractLeaseRenewalServiceTest.java Wed Jan  2 05:20:52 2013
@@ -42,18 +42,19 @@ import com.sun.jini.qa.harness.TestExcep
 
 // com.sun.jini.qa
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 
 // net.jini
+import com.sun.jini.qa.harness.Test;
 import net.jini.config.Configuration;
 import net.jini.config.ConfigurationException;
 import net.jini.export.Exporter;
 
 /**
  * This class performs common setup tasks for all
  * LeaseRenewalServiceTests.
  */
-public abstract class AbstractLeaseRenewalServiceTest extends QATest {
+public abstract class AbstractLeaseRenewalServiceTest extends QATestEnvironment implements Test {
 
     /**
      * The test configuration object
@@ -78,10 +79,10 @@ public abstract class AbstractLeaseRenew
     /**
      * Sets up the testing environment.
      */
-    public void setup(QAConfig config) throws Exception {
+    public Test construct(QAConfig config) throws Exception {
 
        // mandatory call to parent
-       super.setup(config);
+       super.construct(config);
 
        testConfiguration = config.getConfiguration();
 	
@@ -110,8 +111,9 @@ public abstract class AbstractLeaseRenew
        // start each service as requested
        for (int i = 0; i < numLRS; i++) {
 	   logger.log(Level.FINE, "Starting LRS service #" + i);
-	   lrsServices.add(manager.startService(serviceName));
+	   lrsServices.add(getManager().startService(serviceName));
        }
+       return this;
     }
 
     /**
@@ -132,7 +134,7 @@ public abstract class AbstractLeaseRenew
      *          If index is greater than or equal to the number of LRS 
      *          proxy instances.
      * 
-     * @see    #setup(QAConfig)
+     * @see    #construct(QAConfig)
      */
     public LeaseRenewalService getLRS(int index) {
 
@@ -153,7 +155,7 @@ public abstract class AbstractLeaseRenew
      *          If index is greater than or equal to the number of LRS 
      *          proxy instances.
      * 
-     * @see    #setup(QAConfig)
+     * @see    #construct(QAConfig)
      */
     public LeaseRenewalService getLRS() {
 	return getLRS(0);
@@ -42,18 +42,19 @@ import com.sun.jini.qa.harness.TestExcep
 
 /**
- * This class performs common setup tasks for all
+ * This class performs common construct tasks for all
  * LeaseRenewalServiceTests.
  */

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AddRemoveTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/renewalservice/AddRemoveTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================